/*********************************************************************************
**
**   $Id: WOPartsForm.cpp,v 1.5 2004/05/24 12:01:05 croftj Exp $
**   Copyright (c) 2004 Joe Croft <joe@croftj.net>
**   
**   This file is part of ah2.
**
**   ah2 is free software; you can redistribute it and/or modify
**   it under the terms of the GNU General Public License as published by
**   the Free Software Foundation; either version 2 of the License, or
**   (at your option) any later version.
**
**   Foobar is distributed in the hope that it will be useful,
**   but WITHOUT ANY WARRANTY; without even the implied warranty of
**   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
**   GNU General Public License for more details.
**
**   You should have received a copy of the GNU General Public License
**   along with Foobar; if not, write to the Free Software
**   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
**
*********************************************************************************/

#include <qlistbox.h>
#include <qmessagebox.h>
#include <qregexp.h>
#include <qsqlquery.h>
#include "WOPartsForm.h"

extern QSqlDatabase *autohouse;

WOPartsForm::WOPartsForm(QWidget *pParent, const char *pName, WFlags f) :
           DataForm(autohouse, "wo_parts", 4, 3, pParent, pName, f)
{
   printf("WOPartsForm::WOPartsForm(): Enter()\n");
   fflush(stdout);
   inTransaction = false;
   descrEdit =       new QLineEdit(this);
   woEdit =          new QLineEdit(this);
   pnEdit =          new QLineEdit(this);
   qtyEdit =         new QLineEdit(this);
   costEdit =        new MoneyEdit(this);
   taxableSelect =   new YesNoSelect(this);
   taxableSelect->setText("Y");
   supplySelect =    new YesNoSelect(this);
   supplySelect->setText("N");

   DataFields fields[] =
   {
      { "workorder", "WorkOrder",      0,  0,  0,  0,  0,  0,  1, "",      woEdit, NULL },
      { "pn",        "Part #",         1,  0,  0,  0,  0,  0,  0, "",      pnEdit, NULL },
      { "descr",     "Description",    1,  1,  0,  0,  0,  0,  0, "",      descrEdit, NULL },
      { "qty",       "Qty",            2,  0,  0,  0,  0,  0,  0, "",      qtyEdit, NULL },
      { "cost",      "Cost",           2,  1,  0,  0,  0,  0,  0, "",      costEdit, "money" },
      { "taxable",   "Taxable",        2,  2,  0,  0,  0,  0,  0, "",      taxableSelect, "yesno" },
      { "supply",    "Supply",         2,  3,  0,  0,  0,  0,  0, "",      supplySelect, "yesno" },
      {  NULL, NULL, 0, 0, 0, 0, 0, 0, 0, NULL, NULL, NULL }
   };
   printf("WOPartsForm::WOPartsForm(): Setting Fields()\n");
   fflush(stdout);
   setFields(fields);
   woEdit->setEnabled(false);
   setEnabled(false);
   printf("WOPartsForm::WOPartsForm(): Exit()\n");
   fflush(stdout);
}

void WOPartsForm::setEnabled(bool b) 
{
   printf("WOPartsForm::setEnabled('%s'): Entry\n", b == 1 ? "true" : "false");
   fflush(stdout);

   descrEdit->setEnabled(b);
   descrEdit->setCursorPosition(0);

   pnEdit->setEnabled(b);
   pnEdit->setCursorPosition(0);

   qtyEdit->setEnabled(b);
   qtyEdit->setCursorPosition(0);

   costEdit->setEnabled(b);
   costEdit->setCursorPosition(0);

   taxableSelect->setEnabled(b);

   supplySelect->setEnabled(b);

   printf("WOPartsForm::setEnabled(): Exit\n");
   fflush(stdout);
}

void WOPartsForm::deleteRecord() 
{
   QString s;
   printf("WOPartsForm::deleteRecord(): Enter()\n");
   fflush(stdout);
   s = "<qt>Deleting part '" +
        descrEdit->text() +
        "'. This operation can not be undone! Are you sure?</qt>"; 
   printf("WOPartsForm::deleteRecord(): Opening Message Box\n");
   fflush(stdout);
   if (QMessageBox::warning(NULL, "Delete Transaction", s, QMessageBox::Yes | QMessageBox::Default, 
                           QMessageBox::No | QMessageBox::Escape) == QMessageBox::Yes) 
   {
      printf("WOPartsForm::deleteRecord(): deleting record()\n");
      fflush(stdout);
      DataForm::deleteRecord();
   }
   printf("WOPartsForm::deleteRecord(): Exit()\n");
   fflush(stdout);
}

void WOPartsForm::insertRecord()
{
   beginTransaction();
   DataForm::insertRecord();  
   taxableSelect->setText("Y");
   printf("WOPartsEdit::insertRecord(): wo = |%s|\n", (const char *)wo);
   if ( wo != "" ) 
   {
      printf("WOPartsEdit::insertRecord(): Setting owner field = |%s|\n", (const char *)wo);
      woEdit->setText(wo);
   }
   setEnabled(true);
}

void WOPartsForm::updateRecord()
{
   beginTransaction();
   if ( wo != "" ) 
   {
      woEdit->setText(wo);
   }
   DataForm::updateRecord();  
   setEnabled(false);
}

void WOPartsForm::beginTransaction()
{
   if ( ! inTransaction ) 
   {
      DataForm::beginTransaction();
      inTransaction = true;
   }
}

void WOPartsForm::commitTransaction()
{
   if ( inTransaction ) 
   {
      DataForm::commitTransaction();
      inTransaction = false;
   }
}

void WOPartsForm::rollbackTransaction()
{
   if ( inTransaction ) 
   {
      DataForm::rollbackTransaction();
      inTransaction = false;
   }
}

void WOPartsForm::setWorkOrder(QString _wo)
{
   printf("WOPartsForm::setOwner(): Setting wo |%s|\n", (const char *)_wo);
   wo = _wo;
}

bool WOPartsForm::isInTransaction()
{
   printf("WOPartsForm::isInTransaction(): inTransaction = %x\n", inTransaction);
   fflush(stdout);
   return(inTransaction);
}

void WOPartsForm::refresh(QSqlRecord *r)
{
   printf("WOPartsForm::isInTransaction(): Enter, inTransaction = %x\n", inTransaction);
   fflush(stdout);
   DataForm::refresh(r);
   setEnabled(true);
   printf("WOPartsForm::isInTransaction(): Exit\n");
   fflush(stdout);
}
